@@ -33,10 +33,11 @@
 #  define KPROPERTYCORE_DEPRECATED_NO_EXPORT KPROPERTYCORE_NO_EXPORT KPROPERTYCORE_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KPROPERTYCORE_NO_DEPRECATED
 #    define KPROPERTYCORE_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* KPROPERTYCORE_EXPORT_H */
